# himatcal

![supported python versions](https://img.shields.io/pypi/pyversions/himatcal)

Some scripts to perform material simulation.

> [!WARNING]
> 🚧 This repository is still under construction. 🚧

